@@ -101,13 +101,13 @@ public:
 
     Q_INVOKABLE void moveWindow(int window, double x, double y, int targetItemId, int sourceItemId,
         qreal widthScaleFactor, qreal heightScaleFactor);
-    Q_INVOKABLE void changePage(int itemId);
+    Q_INVOKABLE void changePage(int page);
     Q_INVOKABLE void drop(QMimeData *mimeData, int itemId);
     Q_INVOKABLE void addDesktop();
     Q_INVOKABLE void removeDesktop();
 
-    void classBegin();
-    void componentComplete();
+    void classBegin() Q_DECL_OVERRIDE;
+    void componentComplete() Q_DECL_OVERRIDE;
 
 Q_SIGNALS:
     void countChanged() const;
